lilypondfiletools.ScoreBlock
============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock

.. autoclass:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.append
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.count
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.extend
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.index
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.insert
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.pop
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.remove
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.reverse
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.sort
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__add__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__contains__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__delitem__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__delslice__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__eq__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__format__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__ge__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__getitem__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__getslice__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__gt__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__iadd__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__imul__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__iter__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__le__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__len__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__lt__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__mul__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__ne__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__repr__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__reversed__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__rmul__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__setitem__
      ~abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.__setslice__
   :noindex:
